#!/usr/bin/perl -w
#*
# *  plog // a blog cms system written in perl using xml for contents
# ****************************************************************************
# *  This source is covered by the GNU GPL http://www.gnu.org
# *  (c) 2003 - 2005 www.strg.at
# *  Software distributed under the License is distributed on an "AS IS"
# *  basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
# *  License for a specific language governing rights and limitations under
# *  the License.
# *
# *  The Initial Developer is: Juergen Schmidt <juergen@strg.at>
# ****************************************************************************/

#/**
# * DESCRIPTION: main executable script
# * @package  plog
# * @author   juergen schmidt <juergen@strg.at>
# * @since    Version 0.1
# * @version  0.1
# * @license  http://gnu.org 
# */
 
 

 my $timestamp = mktime(localtime());
 
 # global perl modules
 use strict;               # set strict perl syntax mode
 use XML::RSS;             # perl rss-parser
 use XML::Parser;          # perl xml-parser
 use Data::Dumper;         # print data from array or object // just for testings
 use HTML::Template;       # perl html-templates
 use CGI qw(:all);         # use as cgi for weboutput
 use POSIX;                # posix setting
 
 # plog modules
 use config;               # plog configuration
 use modules::plog;        # plog perl module

 # variables and objects initialization
 my $x=0;
 my $item;
 my $coretpl;
 my @blog;   # data array for blog
 my @vers;   # data array for versions
 my @about;  # data array for about
 my $html;
 my $plog = new modules::plog;
 my $rss = new XML::RSS; 
 my $cgi = new CGI;
 my $template = HTML::Template->new(type              => 'filename',
                                    source            => $config::tmpl . '/' . $config::tmpl::start,
																		case_sensitive    => $config::tmpl::case,
																		die_on_bad_params => $config::tmpl::badparams);


 #my $path = $cgi->path_info();
 my $path = "link/page/22/";
 my $software = $cgi->server_software();
 my $host = $cgi->remote_host();

 my %argv = $plog->createArgv($path);
 
 # parse blog-file and write contents to array // print qq{<A HREF="$i->{'link'}">$i->RSS and You</A>};
 $rss->parsefile($config::blog);
 for $item (@{$rss->{items}}) {
   $item->{'content'} = $plog->parseData($item->{'content'});
   $item->{'description'} = $plog->parseData($item->{'description'});
	 $blog[$x] = $item;
   $x++;
 } # for

 $rss->parsefile($config::about);
 for $item (@{$rss->{items}}) {
   $item->{'content'} = $plog->parseData($item->{'content'});
   $item->{'description'} = $plog->parseData($item->{'description'});
	 $about[$x] = $item;
   $x++;
 } # for
 
 $rss->parsefile($config::vers);
 for $item (@{$rss->{items}}) {
	 $vers[$x] = $item;
   $x++;
 } # for

 # assign default values for templates
 $template->param(action => $argv{"action"});
 $template->param(page => $argv{"page"});
 $template->param(count => $argv{"count"});
 $template->param(host => $config::host); 

 $template->param(software => $software); 
 $template->param(blog => \@blog);
 $template->param(vers => \@vers);
 $template->param(about => \@about);
 $template->param(title => $config::title);
 $template->param(time => mktime(localtime()) - $timestamp);

# create hmtl-pages in the file system
 $template->param(abouttpl => 1);
 $html = $template->output();
 $plog->createPage("about.html", $template->output());

 $template->param(blogtpl => 1);
 $html = $template->output();
 $plog->createPage("index.html", $template->output());


 print "\n\n end of plog all pages created \n\n";
 #print "\n\n" . $config::host . " needed " . $time . " to run plog.pl\n\n";

# end main
